==> qtjambi-charts-debuginfo-macos-5.15.20.jar: sources/QtJambiCharts/QBoxPlotModelMapper_shell.h <==
#ifndef QBOXPLOTMODELMAPPER_SHELL_H
#define QBOXPLOTMODELMAPPER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCharts/qboxplotmodelmapper.h>
#include <QtJambi/QtJambiAPI>
#include <QtCharts/qboxplotseries.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QBoxPlotModelMapper_shell : public QtCharts::QBoxPlotModelMapper, public QtJambiShellInterface
{
public:
    QBoxPlotModelMapper_shell(QObject* parent0 = nullptr);
    ~QBoxPlotModelMapper_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QBoxPlotModelMapper_access : public QtCharts::QBoxPlotModelMapper
{
    jint __qt_count_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_first_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_firstBoxSetSection_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_lastBoxSetSection_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_model_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_orientation_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_series_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setCount_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint count0);
    void __qt_setFirst_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint first0);
    void __qt_setFirstBoxSetSection_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint firstBoxSetSection0);
    void __qt_setLastBoxSetSection_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint lastBoxSetSection0);
    void __qt_setModel_QAbstractItemModel_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID model0);
    void __qt_setOrientation_Qt_Orientation(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint orientation0);
    void __qt_setSeries_QtCharts_QBoxPlotSeries_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID series0);
};

#endif // QBOXPLOTMODELMAPPER_SHELL_H

==> qtjambi-charts-debuginfo-macos-6.5.3.jar: sources/QtJambiCharts/QBoxPlotModelMapper_shell.h <==
#ifndef QBOXPLOTMODELMAPPER_SHELL_H
#define QBOXPLOTMODELMAPPER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtCharts/qboxplotmodelmapper.h>
#include <QtJambi/QtJambiAPI>
#include <QtCharts/qboxplotseries.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QBoxPlotModelMapper_shell : public QBoxPlotModelMapper, public QtJambiShellInterface
{
public:
    QBoxPlotModelMapper_shell(QObject* parent0 = nullptr);
    ~QBoxPlotModelMapper_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QBoxPlotModelMapper_access : public QBoxPlotModelMapper
{
    jint __qt_count(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_first(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_firstBoxSetSection(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_lastBoxSetSection(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_model(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_orientation(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_series(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setCount_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint count0);
    void __qt_setFirst_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint first0);
    void __qt_setFirstBoxSetSection_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint firstBoxSetSection0);
    void __qt_setLastBoxSetSection_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint lastBoxSetSection0);
    void __qt_setModel_QAbstractItemModel_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID model0);
    void __qt_setOrientation_Qt_Orientation(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint orientation0);
    void __qt_setSeries_QBoxPlotSeries_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID series0);
};

#endif // QBOXPLOTMODELMAPPER_SHELL_H
